django-awl
**********

Yet another catch-all of tools for django.  Includes utilities for admin,
context processors, CSS colours, view and model mixins, template tags and
unit testing.


Installation
============

.. code-block:: bash

    $ pip install django-awl

Supports
========

django-awl has been tested with Python 2.7, 3.4, 3.5 and Django 1.8, 1.9 and
1.10.

Docs
====

Docs available at: http://django-awl.readthedocs.io/en/latest/
